@@ -34,6 +34,8 @@ class TestCMS(NereidTestCase):
         self.Website = POOL.get('nereid.website')
         self.ArticleAttribute = POOL.get('nereid.cms.article.attribute')
         self.Party = POOL.get('party.party')
+        self.MenuItem = POOL.get('nereid.cms.menuitem')
+        self.Link = POOL.get('nereid.cms.link')
 
         self.templates = {
             'home.jinja':
@@ -201,6 +203,18 @@ class TestCMS(NereidTestCase):
             self.Article.delete([article1])
             self.assertEqual(self.ArticleAttribute.search([], count=True), 0)
 
+    def test_0060_create_menu_item(self):
+        '''
+        Test creating a new menu item
+        '''
+        with Transaction().start(DB_NAME, USER, CONTEXT):
+            menuitem, = self.MenuItem.create([{
+                'title': 'MenuItem',
+                'unique_name': 'MenuItem',
+                'sequence': 1
+            }])
+            self.assert_(menuitem)
+
 
 def suite():
     "CMS test suite"
